@@ -6,11 +6,16 @@ autocomplete_light_autocomplete
     routes to AutocompleteView.
 """
 
-from django.conf.urls.defaults import patterns, url
+try:
+    from django.conf.urls.defaults import patterns, url
+except ImportError:
+    from django.conf.urls import patterns, url
+
 from django.views.generic.base import TemplateView
 
 from views import AutocompleteView, RegistryView
 
+
 urlpatterns = patterns('',
     url(r'^(?P<autocomplete>[-\w]+)/$',
         AutocompleteView.as_view(),
